// Compiled by ClojureScript 0.0-2234
goog.provide('tamarack.components.debug');
goog.require('cljs.core');
goog.require('sablono.core');
goog.require('sablono.core');
goog.require('om.core');
goog.require('om.core');
tamarack.components.debug.component = (function component(app,owner){if(typeof tamarack.components.debug.t6995 !== 'undefined')
{} else
{
/**
* @constructor
*/
tamarack.components.debug.t6995 = (function (owner,app,component,meta6996){
this.owner = owner;
this.app = app;
this.component = component;
this.meta6996 = meta6996;
this.cljs$lang$protocol_mask$partition1$ = 0;
this.cljs$lang$protocol_mask$partition0$ = 393216;
})
tamarack.components.debug.t6995.cljs$lang$type = true;
tamarack.components.debug.t6995.cljs$lang$ctorStr = "tamarack.components.debug/t6995";
tamarack.components.debug.t6995.cljs$lang$ctorPrWriter = (function (this__4140__auto__,writer__4141__auto__,opt__4142__auto__){return cljs.core._write.call(null,writer__4141__auto__,"tamarack.components.debug/t6995");
});
tamarack.components.debug.t6995.prototype.om$core$IRender$ = true;
tamarack.components.debug.t6995.prototype.om$core$IRender$render$arity$1 = (function (_){var self__ = this;
var ___$1 = this;var attrs6998 = cljs.core.pr_str.call(null,self__.app);return cljs.core.apply.call(null,React.DOM.pre,((cljs.core.map_QMARK_.call(null,attrs6998))?sablono.interpreter.attributes.call(null,attrs6998):null),cljs.core.remove.call(null,cljs.core.nil_QMARK_,((cljs.core.map_QMARK_.call(null,attrs6998))?cljs.core.PersistentVector.EMPTY:new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [sablono.interpreter.interpret.call(null,attrs6998)], null))));
});
tamarack.components.debug.t6995.prototype.om$core$IDisplayName$ = true;
tamarack.components.debug.t6995.prototype.om$core$IDisplayName$display_name$arity$1 = (function (_){var self__ = this;
var ___$1 = this;return "StateDebug";
});
tamarack.components.debug.t6995.prototype.cljs$core$IMeta$_meta$arity$1 = (function (_6997){var self__ = this;
var _6997__$1 = this;return self__.meta6996;
});
tamarack.components.debug.t6995.prototype.cljs$core$IWithMeta$_with_meta$arity$2 = (function (_6997,meta6996__$1){var self__ = this;
var _6997__$1 = this;return (new tamarack.components.debug.t6995(self__.owner,self__.app,self__.component,meta6996__$1));
});
tamarack.components.debug.__GT_t6995 = (function __GT_t6995(owner__$1,app__$1,component__$1,meta6996){return (new tamarack.components.debug.t6995(owner__$1,app__$1,component__$1,meta6996));
});
}
return (new tamarack.components.debug.t6995(owner,app,component,null));
});

//# sourceMappingURL=debug.js.map