#date-dropdown {
    width: 520px;
    padding: 10px;
}

#date-dropdown .nav {
    padding: 5px 5px 15px;
}

.list-group-item.heading {
    text-transform: uppercase;
    color: #777;
    font-size: 12px;
    padding-top: 24px;
    padding-bottom: 8px;
}

.navbar-toplevel {
    border-top: 0;
    border-left: 0;
    border-right: 0;
    border-radius: 0;
    background-color: #dddee0;
}

#sidebar {
    background-color: #dddee0;
    height: 100%;
    border-right: 1px solid #e7e7e7;
}

.sidebar-container {
    height: 100%;
}

.sidebar-header.navbar {
    margin-bottom: 0;
    border-bottom: 0;
}

.innermost-sidebar-container {
    padding-bottom: 50px;
}

html, body {
    height: 100%;
    font-family: Lato, sans-serif;
}

a {
    color: #1964AC;
}

.navbar .navbar-brand a {
    font-weight: 300;
    text-transform: uppercase;
    color: #53585f;
    font-size: 24px;
}

.navbar .navbar-brand a:hover {
    text-decoration: none;
}

.navbar .navbar-nav li a {
    color: #53585f;
    font-weight: 300;
}

#sidebar ol {
    margin-top: 21px;
    padding-left: 0;
}

#sidebar li {
    list-style: none;
    margin: 5px 0;
}

#sidebar a {
    display: block;
    padding: 10px 0 10px 20px;
    font-weight: bold;
}

#sidebar .fa {
    display: inline-block;
    width: 2.5ex;
    margin-right: 1ex;
}

#sidebar .active {
    background-color: #d3d5da;
}

td.num-col {
    text-align: right;
}
