// Compiled by ClojureScript 0.0-2234
goog.provide('om.dom');
goog.require('cljs.core');
/**
* @param {...*} var_args
*/
om.dom.a = (function() { 
var a__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.a.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var a = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return a__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
a.cljs$lang$maxFixedArity = 1;
a.cljs$lang$applyTo = (function (arglist__8716){
var opts__6682__auto__ = cljs.core.first(arglist__8716);
var children__6683__auto__ = cljs.core.rest(arglist__8716);
return a__delegate(opts__6682__auto__,children__6683__auto__);
});
a.cljs$core$IFn$_invoke$arity$variadic = a__delegate;
return a;
})()
;
/**
* @param {...*} var_args
*/
om.dom.abbr = (function() { 
var abbr__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.abbr.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var abbr = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return abbr__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
abbr.cljs$lang$maxFixedArity = 1;
abbr.cljs$lang$applyTo = (function (arglist__8717){
var opts__6682__auto__ = cljs.core.first(arglist__8717);
var children__6683__auto__ = cljs.core.rest(arglist__8717);
return abbr__delegate(opts__6682__auto__,children__6683__auto__);
});
abbr.cljs$core$IFn$_invoke$arity$variadic = abbr__delegate;
return abbr;
})()
;
/**
* @param {...*} var_args
*/
om.dom.address = (function() { 
var address__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.address.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var address = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return address__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
address.cljs$lang$maxFixedArity = 1;
address.cljs$lang$applyTo = (function (arglist__8718){
var opts__6682__auto__ = cljs.core.first(arglist__8718);
var children__6683__auto__ = cljs.core.rest(arglist__8718);
return address__delegate(opts__6682__auto__,children__6683__auto__);
});
address.cljs$core$IFn$_invoke$arity$variadic = address__delegate;
return address;
})()
;
/**
* @param {...*} var_args
*/
om.dom.area = (function() { 
var area__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.area.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var area = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return area__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
area.cljs$lang$maxFixedArity = 1;
area.cljs$lang$applyTo = (function (arglist__8719){
var opts__6682__auto__ = cljs.core.first(arglist__8719);
var children__6683__auto__ = cljs.core.rest(arglist__8719);
return area__delegate(opts__6682__auto__,children__6683__auto__);
});
area.cljs$core$IFn$_invoke$arity$variadic = area__delegate;
return area;
})()
;
/**
* @param {...*} var_args
*/
om.dom.article = (function() { 
var article__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.article.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var article = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return article__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
article.cljs$lang$maxFixedArity = 1;
article.cljs$lang$applyTo = (function (arglist__8720){
var opts__6682__auto__ = cljs.core.first(arglist__8720);
var children__6683__auto__ = cljs.core.rest(arglist__8720);
return article__delegate(opts__6682__auto__,children__6683__auto__);
});
article.cljs$core$IFn$_invoke$arity$variadic = article__delegate;
return article;
})()
;
/**
* @param {...*} var_args
*/
om.dom.aside = (function() { 
var aside__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.aside.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var aside = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return aside__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
aside.cljs$lang$maxFixedArity = 1;
aside.cljs$lang$applyTo = (function (arglist__8721){
var opts__6682__auto__ = cljs.core.first(arglist__8721);
var children__6683__auto__ = cljs.core.rest(arglist__8721);
return aside__delegate(opts__6682__auto__,children__6683__auto__);
});
aside.cljs$core$IFn$_invoke$arity$variadic = aside__delegate;
return aside;
})()
;
/**
* @param {...*} var_args
*/
om.dom.audio = (function() { 
var audio__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.audio.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var audio = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return audio__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
audio.cljs$lang$maxFixedArity = 1;
audio.cljs$lang$applyTo = (function (arglist__8722){
var opts__6682__auto__ = cljs.core.first(arglist__8722);
var children__6683__auto__ = cljs.core.rest(arglist__8722);
return audio__delegate(opts__6682__auto__,children__6683__auto__);
});
audio.cljs$core$IFn$_invoke$arity$variadic = audio__delegate;
return audio;
})()
;
/**
* @param {...*} var_args
*/
om.dom.b = (function() { 
var b__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.b.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var b = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return b__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
b.cljs$lang$maxFixedArity = 1;
b.cljs$lang$applyTo = (function (arglist__8723){
var opts__6682__auto__ = cljs.core.first(arglist__8723);
var children__6683__auto__ = cljs.core.rest(arglist__8723);
return b__delegate(opts__6682__auto__,children__6683__auto__);
});
b.cljs$core$IFn$_invoke$arity$variadic = b__delegate;
return b;
})()
;
/**
* @param {...*} var_args
*/
om.dom.base = (function() { 
var base__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.base.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var base = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return base__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
base.cljs$lang$maxFixedArity = 1;
base.cljs$lang$applyTo = (function (arglist__8724){
var opts__6682__auto__ = cljs.core.first(arglist__8724);
var children__6683__auto__ = cljs.core.rest(arglist__8724);
return base__delegate(opts__6682__auto__,children__6683__auto__);
});
base.cljs$core$IFn$_invoke$arity$variadic = base__delegate;
return base;
})()
;
/**
* @param {...*} var_args
*/
om.dom.bdi = (function() { 
var bdi__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.bdi.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var bdi = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return bdi__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
bdi.cljs$lang$maxFixedArity = 1;
bdi.cljs$lang$applyTo = (function (arglist__8725){
var opts__6682__auto__ = cljs.core.first(arglist__8725);
var children__6683__auto__ = cljs.core.rest(arglist__8725);
return bdi__delegate(opts__6682__auto__,children__6683__auto__);
});
bdi.cljs$core$IFn$_invoke$arity$variadic = bdi__delegate;
return bdi;
})()
;
/**
* @param {...*} var_args
*/
om.dom.bdo = (function() { 
var bdo__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.bdo.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var bdo = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return bdo__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
bdo.cljs$lang$maxFixedArity = 1;
bdo.cljs$lang$applyTo = (function (arglist__8726){
var opts__6682__auto__ = cljs.core.first(arglist__8726);
var children__6683__auto__ = cljs.core.rest(arglist__8726);
return bdo__delegate(opts__6682__auto__,children__6683__auto__);
});
bdo.cljs$core$IFn$_invoke$arity$variadic = bdo__delegate;
return bdo;
})()
;
/**
* @param {...*} var_args
*/
om.dom.big = (function() { 
var big__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.big.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var big = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return big__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
big.cljs$lang$maxFixedArity = 1;
big.cljs$lang$applyTo = (function (arglist__8727){
var opts__6682__auto__ = cljs.core.first(arglist__8727);
var children__6683__auto__ = cljs.core.rest(arglist__8727);
return big__delegate(opts__6682__auto__,children__6683__auto__);
});
big.cljs$core$IFn$_invoke$arity$variadic = big__delegate;
return big;
})()
;
/**
* @param {...*} var_args
*/
om.dom.blockquote = (function() { 
var blockquote__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.blockquote.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var blockquote = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return blockquote__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
blockquote.cljs$lang$maxFixedArity = 1;
blockquote.cljs$lang$applyTo = (function (arglist__8728){
var opts__6682__auto__ = cljs.core.first(arglist__8728);
var children__6683__auto__ = cljs.core.rest(arglist__8728);
return blockquote__delegate(opts__6682__auto__,children__6683__auto__);
});
blockquote.cljs$core$IFn$_invoke$arity$variadic = blockquote__delegate;
return blockquote;
})()
;
/**
* @param {...*} var_args
*/
om.dom.body = (function() { 
var body__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.body.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var body = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return body__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
body.cljs$lang$maxFixedArity = 1;
body.cljs$lang$applyTo = (function (arglist__8729){
var opts__6682__auto__ = cljs.core.first(arglist__8729);
var children__6683__auto__ = cljs.core.rest(arglist__8729);
return body__delegate(opts__6682__auto__,children__6683__auto__);
});
body.cljs$core$IFn$_invoke$arity$variadic = body__delegate;
return body;
})()
;
/**
* @param {...*} var_args
*/
om.dom.br = (function() { 
var br__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.br.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var br = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return br__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
br.cljs$lang$maxFixedArity = 1;
br.cljs$lang$applyTo = (function (arglist__8730){
var opts__6682__auto__ = cljs.core.first(arglist__8730);
var children__6683__auto__ = cljs.core.rest(arglist__8730);
return br__delegate(opts__6682__auto__,children__6683__auto__);
});
br.cljs$core$IFn$_invoke$arity$variadic = br__delegate;
return br;
})()
;
/**
* @param {...*} var_args
*/
om.dom.button = (function() { 
var button__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.button.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var button = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return button__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
button.cljs$lang$maxFixedArity = 1;
button.cljs$lang$applyTo = (function (arglist__8731){
var opts__6682__auto__ = cljs.core.first(arglist__8731);
var children__6683__auto__ = cljs.core.rest(arglist__8731);
return button__delegate(opts__6682__auto__,children__6683__auto__);
});
button.cljs$core$IFn$_invoke$arity$variadic = button__delegate;
return button;
})()
;
/**
* @param {...*} var_args
*/
om.dom.canvas = (function() { 
var canvas__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.canvas.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var canvas = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return canvas__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
canvas.cljs$lang$maxFixedArity = 1;
canvas.cljs$lang$applyTo = (function (arglist__8732){
var opts__6682__auto__ = cljs.core.first(arglist__8732);
var children__6683__auto__ = cljs.core.rest(arglist__8732);
return canvas__delegate(opts__6682__auto__,children__6683__auto__);
});
canvas.cljs$core$IFn$_invoke$arity$variadic = canvas__delegate;
return canvas;
})()
;
/**
* @param {...*} var_args
*/
om.dom.caption = (function() { 
var caption__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.caption.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var caption = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return caption__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
caption.cljs$lang$maxFixedArity = 1;
caption.cljs$lang$applyTo = (function (arglist__8733){
var opts__6682__auto__ = cljs.core.first(arglist__8733);
var children__6683__auto__ = cljs.core.rest(arglist__8733);
return caption__delegate(opts__6682__auto__,children__6683__auto__);
});
caption.cljs$core$IFn$_invoke$arity$variadic = caption__delegate;
return caption;
})()
;
/**
* @param {...*} var_args
*/
om.dom.cite = (function() { 
var cite__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.cite.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var cite = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return cite__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
cite.cljs$lang$maxFixedArity = 1;
cite.cljs$lang$applyTo = (function (arglist__8734){
var opts__6682__auto__ = cljs.core.first(arglist__8734);
var children__6683__auto__ = cljs.core.rest(arglist__8734);
return cite__delegate(opts__6682__auto__,children__6683__auto__);
});
cite.cljs$core$IFn$_invoke$arity$variadic = cite__delegate;
return cite;
})()
;
/**
* @param {...*} var_args
*/
om.dom.code = (function() { 
var code__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.code.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var code = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return code__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
code.cljs$lang$maxFixedArity = 1;
code.cljs$lang$applyTo = (function (arglist__8735){
var opts__6682__auto__ = cljs.core.first(arglist__8735);
var children__6683__auto__ = cljs.core.rest(arglist__8735);
return code__delegate(opts__6682__auto__,children__6683__auto__);
});
code.cljs$core$IFn$_invoke$arity$variadic = code__delegate;
return code;
})()
;
/**
* @param {...*} var_args
*/
om.dom.col = (function() { 
var col__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.col.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var col = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return col__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
col.cljs$lang$maxFixedArity = 1;
col.cljs$lang$applyTo = (function (arglist__8736){
var opts__6682__auto__ = cljs.core.first(arglist__8736);
var children__6683__auto__ = cljs.core.rest(arglist__8736);
return col__delegate(opts__6682__auto__,children__6683__auto__);
});
col.cljs$core$IFn$_invoke$arity$variadic = col__delegate;
return col;
})()
;
/**
* @param {...*} var_args
*/
om.dom.colgroup = (function() { 
var colgroup__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.colgroup.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var colgroup = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return colgroup__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
colgroup.cljs$lang$maxFixedArity = 1;
colgroup.cljs$lang$applyTo = (function (arglist__8737){
var opts__6682__auto__ = cljs.core.first(arglist__8737);
var children__6683__auto__ = cljs.core.rest(arglist__8737);
return colgroup__delegate(opts__6682__auto__,children__6683__auto__);
});
colgroup.cljs$core$IFn$_invoke$arity$variadic = colgroup__delegate;
return colgroup;
})()
;
/**
* @param {...*} var_args
*/
om.dom.data = (function() { 
var data__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.data.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var data = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return data__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
data.cljs$lang$maxFixedArity = 1;
data.cljs$lang$applyTo = (function (arglist__8738){
var opts__6682__auto__ = cljs.core.first(arglist__8738);
var children__6683__auto__ = cljs.core.rest(arglist__8738);
return data__delegate(opts__6682__auto__,children__6683__auto__);
});
data.cljs$core$IFn$_invoke$arity$variadic = data__delegate;
return data;
})()
;
/**
* @param {...*} var_args
*/
om.dom.datalist = (function() { 
var datalist__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.datalist.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var datalist = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return datalist__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
datalist.cljs$lang$maxFixedArity = 1;
datalist.cljs$lang$applyTo = (function (arglist__8739){
var opts__6682__auto__ = cljs.core.first(arglist__8739);
var children__6683__auto__ = cljs.core.rest(arglist__8739);
return datalist__delegate(opts__6682__auto__,children__6683__auto__);
});
datalist.cljs$core$IFn$_invoke$arity$variadic = datalist__delegate;
return datalist;
})()
;
/**
* @param {...*} var_args
*/
om.dom.dd = (function() { 
var dd__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.dd.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var dd = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return dd__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
dd.cljs$lang$maxFixedArity = 1;
dd.cljs$lang$applyTo = (function (arglist__8740){
var opts__6682__auto__ = cljs.core.first(arglist__8740);
var children__6683__auto__ = cljs.core.rest(arglist__8740);
return dd__delegate(opts__6682__auto__,children__6683__auto__);
});
dd.cljs$core$IFn$_invoke$arity$variadic = dd__delegate;
return dd;
})()
;
/**
* @param {...*} var_args
*/
om.dom.del = (function() { 
var del__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.del.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var del = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return del__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
del.cljs$lang$maxFixedArity = 1;
del.cljs$lang$applyTo = (function (arglist__8741){
var opts__6682__auto__ = cljs.core.first(arglist__8741);
var children__6683__auto__ = cljs.core.rest(arglist__8741);
return del__delegate(opts__6682__auto__,children__6683__auto__);
});
del.cljs$core$IFn$_invoke$arity$variadic = del__delegate;
return del;
})()
;
/**
* @param {...*} var_args
*/
om.dom.dfn = (function() { 
var dfn__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.dfn.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var dfn = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return dfn__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
dfn.cljs$lang$maxFixedArity = 1;
dfn.cljs$lang$applyTo = (function (arglist__8742){
var opts__6682__auto__ = cljs.core.first(arglist__8742);
var children__6683__auto__ = cljs.core.rest(arglist__8742);
return dfn__delegate(opts__6682__auto__,children__6683__auto__);
});
dfn.cljs$core$IFn$_invoke$arity$variadic = dfn__delegate;
return dfn;
})()
;
/**
* @param {...*} var_args
*/
om.dom.div = (function() { 
var div__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.div.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var div = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return div__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
div.cljs$lang$maxFixedArity = 1;
div.cljs$lang$applyTo = (function (arglist__8743){
var opts__6682__auto__ = cljs.core.first(arglist__8743);
var children__6683__auto__ = cljs.core.rest(arglist__8743);
return div__delegate(opts__6682__auto__,children__6683__auto__);
});
div.cljs$core$IFn$_invoke$arity$variadic = div__delegate;
return div;
})()
;
/**
* @param {...*} var_args
*/
om.dom.dl = (function() { 
var dl__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.dl.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var dl = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return dl__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
dl.cljs$lang$maxFixedArity = 1;
dl.cljs$lang$applyTo = (function (arglist__8744){
var opts__6682__auto__ = cljs.core.first(arglist__8744);
var children__6683__auto__ = cljs.core.rest(arglist__8744);
return dl__delegate(opts__6682__auto__,children__6683__auto__);
});
dl.cljs$core$IFn$_invoke$arity$variadic = dl__delegate;
return dl;
})()
;
/**
* @param {...*} var_args
*/
om.dom.dt = (function() { 
var dt__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.dt.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var dt = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return dt__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
dt.cljs$lang$maxFixedArity = 1;
dt.cljs$lang$applyTo = (function (arglist__8745){
var opts__6682__auto__ = cljs.core.first(arglist__8745);
var children__6683__auto__ = cljs.core.rest(arglist__8745);
return dt__delegate(opts__6682__auto__,children__6683__auto__);
});
dt.cljs$core$IFn$_invoke$arity$variadic = dt__delegate;
return dt;
})()
;
/**
* @param {...*} var_args
*/
om.dom.em = (function() { 
var em__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.em.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var em = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return em__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
em.cljs$lang$maxFixedArity = 1;
em.cljs$lang$applyTo = (function (arglist__8746){
var opts__6682__auto__ = cljs.core.first(arglist__8746);
var children__6683__auto__ = cljs.core.rest(arglist__8746);
return em__delegate(opts__6682__auto__,children__6683__auto__);
});
em.cljs$core$IFn$_invoke$arity$variadic = em__delegate;
return em;
})()
;
/**
* @param {...*} var_args
*/
om.dom.embed = (function() { 
var embed__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.embed.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var embed = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return embed__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
embed.cljs$lang$maxFixedArity = 1;
embed.cljs$lang$applyTo = (function (arglist__8747){
var opts__6682__auto__ = cljs.core.first(arglist__8747);
var children__6683__auto__ = cljs.core.rest(arglist__8747);
return embed__delegate(opts__6682__auto__,children__6683__auto__);
});
embed.cljs$core$IFn$_invoke$arity$variadic = embed__delegate;
return embed;
})()
;
/**
* @param {...*} var_args
*/
om.dom.fieldset = (function() { 
var fieldset__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.fieldset.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var fieldset = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return fieldset__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
fieldset.cljs$lang$maxFixedArity = 1;
fieldset.cljs$lang$applyTo = (function (arglist__8748){
var opts__6682__auto__ = cljs.core.first(arglist__8748);
var children__6683__auto__ = cljs.core.rest(arglist__8748);
return fieldset__delegate(opts__6682__auto__,children__6683__auto__);
});
fieldset.cljs$core$IFn$_invoke$arity$variadic = fieldset__delegate;
return fieldset;
})()
;
/**
* @param {...*} var_args
*/
om.dom.figcaption = (function() { 
var figcaption__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.figcaption.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var figcaption = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return figcaption__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
figcaption.cljs$lang$maxFixedArity = 1;
figcaption.cljs$lang$applyTo = (function (arglist__8749){
var opts__6682__auto__ = cljs.core.first(arglist__8749);
var children__6683__auto__ = cljs.core.rest(arglist__8749);
return figcaption__delegate(opts__6682__auto__,children__6683__auto__);
});
figcaption.cljs$core$IFn$_invoke$arity$variadic = figcaption__delegate;
return figcaption;
})()
;
/**
* @param {...*} var_args
*/
om.dom.figure = (function() { 
var figure__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.figure.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var figure = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return figure__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
figure.cljs$lang$maxFixedArity = 1;
figure.cljs$lang$applyTo = (function (arglist__8750){
var opts__6682__auto__ = cljs.core.first(arglist__8750);
var children__6683__auto__ = cljs.core.rest(arglist__8750);
return figure__delegate(opts__6682__auto__,children__6683__auto__);
});
figure.cljs$core$IFn$_invoke$arity$variadic = figure__delegate;
return figure;
})()
;
/**
* @param {...*} var_args
*/
om.dom.footer = (function() { 
var footer__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.footer.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var footer = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return footer__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
footer.cljs$lang$maxFixedArity = 1;
footer.cljs$lang$applyTo = (function (arglist__8751){
var opts__6682__auto__ = cljs.core.first(arglist__8751);
var children__6683__auto__ = cljs.core.rest(arglist__8751);
return footer__delegate(opts__6682__auto__,children__6683__auto__);
});
footer.cljs$core$IFn$_invoke$arity$variadic = footer__delegate;
return footer;
})()
;
/**
* @param {...*} var_args
*/
om.dom.form = (function() { 
var form__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.form.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var form = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return form__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
form.cljs$lang$maxFixedArity = 1;
form.cljs$lang$applyTo = (function (arglist__8752){
var opts__6682__auto__ = cljs.core.first(arglist__8752);
var children__6683__auto__ = cljs.core.rest(arglist__8752);
return form__delegate(opts__6682__auto__,children__6683__auto__);
});
form.cljs$core$IFn$_invoke$arity$variadic = form__delegate;
return form;
})()
;
/**
* @param {...*} var_args
*/
om.dom.h1 = (function() { 
var h1__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.h1.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var h1 = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return h1__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
h1.cljs$lang$maxFixedArity = 1;
h1.cljs$lang$applyTo = (function (arglist__8753){
var opts__6682__auto__ = cljs.core.first(arglist__8753);
var children__6683__auto__ = cljs.core.rest(arglist__8753);
return h1__delegate(opts__6682__auto__,children__6683__auto__);
});
h1.cljs$core$IFn$_invoke$arity$variadic = h1__delegate;
return h1;
})()
;
/**
* @param {...*} var_args
*/
om.dom.h2 = (function() { 
var h2__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.h2.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var h2 = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return h2__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
h2.cljs$lang$maxFixedArity = 1;
h2.cljs$lang$applyTo = (function (arglist__8754){
var opts__6682__auto__ = cljs.core.first(arglist__8754);
var children__6683__auto__ = cljs.core.rest(arglist__8754);
return h2__delegate(opts__6682__auto__,children__6683__auto__);
});
h2.cljs$core$IFn$_invoke$arity$variadic = h2__delegate;
return h2;
})()
;
/**
* @param {...*} var_args
*/
om.dom.h3 = (function() { 
var h3__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.h3.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var h3 = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return h3__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
h3.cljs$lang$maxFixedArity = 1;
h3.cljs$lang$applyTo = (function (arglist__8755){
var opts__6682__auto__ = cljs.core.first(arglist__8755);
var children__6683__auto__ = cljs.core.rest(arglist__8755);
return h3__delegate(opts__6682__auto__,children__6683__auto__);
});
h3.cljs$core$IFn$_invoke$arity$variadic = h3__delegate;
return h3;
})()
;
/**
* @param {...*} var_args
*/
om.dom.h4 = (function() { 
var h4__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.h4.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var h4 = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return h4__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
h4.cljs$lang$maxFixedArity = 1;
h4.cljs$lang$applyTo = (function (arglist__8756){
var opts__6682__auto__ = cljs.core.first(arglist__8756);
var children__6683__auto__ = cljs.core.rest(arglist__8756);
return h4__delegate(opts__6682__auto__,children__6683__auto__);
});
h4.cljs$core$IFn$_invoke$arity$variadic = h4__delegate;
return h4;
})()
;
/**
* @param {...*} var_args
*/
om.dom.h5 = (function() { 
var h5__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.h5.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var h5 = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return h5__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
h5.cljs$lang$maxFixedArity = 1;
h5.cljs$lang$applyTo = (function (arglist__8757){
var opts__6682__auto__ = cljs.core.first(arglist__8757);
var children__6683__auto__ = cljs.core.rest(arglist__8757);
return h5__delegate(opts__6682__auto__,children__6683__auto__);
});
h5.cljs$core$IFn$_invoke$arity$variadic = h5__delegate;
return h5;
})()
;
/**
* @param {...*} var_args
*/
om.dom.h6 = (function() { 
var h6__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.h6.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var h6 = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return h6__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
h6.cljs$lang$maxFixedArity = 1;
h6.cljs$lang$applyTo = (function (arglist__8758){
var opts__6682__auto__ = cljs.core.first(arglist__8758);
var children__6683__auto__ = cljs.core.rest(arglist__8758);
return h6__delegate(opts__6682__auto__,children__6683__auto__);
});
h6.cljs$core$IFn$_invoke$arity$variadic = h6__delegate;
return h6;
})()
;
/**
* @param {...*} var_args
*/
om.dom.head = (function() { 
var head__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.head.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var head = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return head__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
head.cljs$lang$maxFixedArity = 1;
head.cljs$lang$applyTo = (function (arglist__8759){
var opts__6682__auto__ = cljs.core.first(arglist__8759);
var children__6683__auto__ = cljs.core.rest(arglist__8759);
return head__delegate(opts__6682__auto__,children__6683__auto__);
});
head.cljs$core$IFn$_invoke$arity$variadic = head__delegate;
return head;
})()
;
/**
* @param {...*} var_args
*/
om.dom.header = (function() { 
var header__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.header.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var header = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return header__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
header.cljs$lang$maxFixedArity = 1;
header.cljs$lang$applyTo = (function (arglist__8760){
var opts__6682__auto__ = cljs.core.first(arglist__8760);
var children__6683__auto__ = cljs.core.rest(arglist__8760);
return header__delegate(opts__6682__auto__,children__6683__auto__);
});
header.cljs$core$IFn$_invoke$arity$variadic = header__delegate;
return header;
})()
;
/**
* @param {...*} var_args
*/
om.dom.hr = (function() { 
var hr__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.hr.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var hr = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return hr__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
hr.cljs$lang$maxFixedArity = 1;
hr.cljs$lang$applyTo = (function (arglist__8761){
var opts__6682__auto__ = cljs.core.first(arglist__8761);
var children__6683__auto__ = cljs.core.rest(arglist__8761);
return hr__delegate(opts__6682__auto__,children__6683__auto__);
});
hr.cljs$core$IFn$_invoke$arity$variadic = hr__delegate;
return hr;
})()
;
/**
* @param {...*} var_args
*/
om.dom.html = (function() { 
var html__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.html.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var html = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return html__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
html.cljs$lang$maxFixedArity = 1;
html.cljs$lang$applyTo = (function (arglist__8762){
var opts__6682__auto__ = cljs.core.first(arglist__8762);
var children__6683__auto__ = cljs.core.rest(arglist__8762);
return html__delegate(opts__6682__auto__,children__6683__auto__);
});
html.cljs$core$IFn$_invoke$arity$variadic = html__delegate;
return html;
})()
;
/**
* @param {...*} var_args
*/
om.dom.i = (function() { 
var i__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.i.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var i = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return i__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
i.cljs$lang$maxFixedArity = 1;
i.cljs$lang$applyTo = (function (arglist__8763){
var opts__6682__auto__ = cljs.core.first(arglist__8763);
var children__6683__auto__ = cljs.core.rest(arglist__8763);
return i__delegate(opts__6682__auto__,children__6683__auto__);
});
i.cljs$core$IFn$_invoke$arity$variadic = i__delegate;
return i;
})()
;
/**
* @param {...*} var_args
*/
om.dom.iframe = (function() { 
var iframe__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.iframe.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var iframe = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return iframe__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
iframe.cljs$lang$maxFixedArity = 1;
iframe.cljs$lang$applyTo = (function (arglist__8764){
var opts__6682__auto__ = cljs.core.first(arglist__8764);
var children__6683__auto__ = cljs.core.rest(arglist__8764);
return iframe__delegate(opts__6682__auto__,children__6683__auto__);
});
iframe.cljs$core$IFn$_invoke$arity$variadic = iframe__delegate;
return iframe;
})()
;
/**
* @param {...*} var_args
*/
om.dom.img = (function() { 
var img__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.img.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var img = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return img__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
img.cljs$lang$maxFixedArity = 1;
img.cljs$lang$applyTo = (function (arglist__8765){
var opts__6682__auto__ = cljs.core.first(arglist__8765);
var children__6683__auto__ = cljs.core.rest(arglist__8765);
return img__delegate(opts__6682__auto__,children__6683__auto__);
});
img.cljs$core$IFn$_invoke$arity$variadic = img__delegate;
return img;
})()
;
/**
* @param {...*} var_args
*/
om.dom.ins = (function() { 
var ins__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.ins.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var ins = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return ins__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
ins.cljs$lang$maxFixedArity = 1;
ins.cljs$lang$applyTo = (function (arglist__8766){
var opts__6682__auto__ = cljs.core.first(arglist__8766);
var children__6683__auto__ = cljs.core.rest(arglist__8766);
return ins__delegate(opts__6682__auto__,children__6683__auto__);
});
ins.cljs$core$IFn$_invoke$arity$variadic = ins__delegate;
return ins;
})()
;
/**
* @param {...*} var_args
*/
om.dom.kbd = (function() { 
var kbd__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.kbd.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var kbd = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return kbd__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
kbd.cljs$lang$maxFixedArity = 1;
kbd.cljs$lang$applyTo = (function (arglist__8767){
var opts__6682__auto__ = cljs.core.first(arglist__8767);
var children__6683__auto__ = cljs.core.rest(arglist__8767);
return kbd__delegate(opts__6682__auto__,children__6683__auto__);
});
kbd.cljs$core$IFn$_invoke$arity$variadic = kbd__delegate;
return kbd;
})()
;
/**
* @param {...*} var_args
*/
om.dom.keygen = (function() { 
var keygen__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.keygen.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var keygen = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return keygen__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
keygen.cljs$lang$maxFixedArity = 1;
keygen.cljs$lang$applyTo = (function (arglist__8768){
var opts__6682__auto__ = cljs.core.first(arglist__8768);
var children__6683__auto__ = cljs.core.rest(arglist__8768);
return keygen__delegate(opts__6682__auto__,children__6683__auto__);
});
keygen.cljs$core$IFn$_invoke$arity$variadic = keygen__delegate;
return keygen;
})()
;
/**
* @param {...*} var_args
*/
om.dom.label = (function() { 
var label__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.label.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var label = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return label__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
label.cljs$lang$maxFixedArity = 1;
label.cljs$lang$applyTo = (function (arglist__8769){
var opts__6682__auto__ = cljs.core.first(arglist__8769);
var children__6683__auto__ = cljs.core.rest(arglist__8769);
return label__delegate(opts__6682__auto__,children__6683__auto__);
});
label.cljs$core$IFn$_invoke$arity$variadic = label__delegate;
return label;
})()
;
/**
* @param {...*} var_args
*/
om.dom.legend = (function() { 
var legend__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.legend.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var legend = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return legend__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
legend.cljs$lang$maxFixedArity = 1;
legend.cljs$lang$applyTo = (function (arglist__8770){
var opts__6682__auto__ = cljs.core.first(arglist__8770);
var children__6683__auto__ = cljs.core.rest(arglist__8770);
return legend__delegate(opts__6682__auto__,children__6683__auto__);
});
legend.cljs$core$IFn$_invoke$arity$variadic = legend__delegate;
return legend;
})()
;
/**
* @param {...*} var_args
*/
om.dom.li = (function() { 
var li__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.li.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var li = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return li__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
li.cljs$lang$maxFixedArity = 1;
li.cljs$lang$applyTo = (function (arglist__8771){
var opts__6682__auto__ = cljs.core.first(arglist__8771);
var children__6683__auto__ = cljs.core.rest(arglist__8771);
return li__delegate(opts__6682__auto__,children__6683__auto__);
});
li.cljs$core$IFn$_invoke$arity$variadic = li__delegate;
return li;
})()
;
/**
* @param {...*} var_args
*/
om.dom.link = (function() { 
var link__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.link.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var link = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return link__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
link.cljs$lang$maxFixedArity = 1;
link.cljs$lang$applyTo = (function (arglist__8772){
var opts__6682__auto__ = cljs.core.first(arglist__8772);
var children__6683__auto__ = cljs.core.rest(arglist__8772);
return link__delegate(opts__6682__auto__,children__6683__auto__);
});
link.cljs$core$IFn$_invoke$arity$variadic = link__delegate;
return link;
})()
;
/**
* @param {...*} var_args
*/
om.dom.main = (function() { 
var main__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.main.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var main = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return main__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
main.cljs$lang$maxFixedArity = 1;
main.cljs$lang$applyTo = (function (arglist__8773){
var opts__6682__auto__ = cljs.core.first(arglist__8773);
var children__6683__auto__ = cljs.core.rest(arglist__8773);
return main__delegate(opts__6682__auto__,children__6683__auto__);
});
main.cljs$core$IFn$_invoke$arity$variadic = main__delegate;
return main;
})()
;
/**
* @param {...*} var_args
*/
om.dom.map = (function() { 
var map__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.map.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var map = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return map__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
map.cljs$lang$maxFixedArity = 1;
map.cljs$lang$applyTo = (function (arglist__8774){
var opts__6682__auto__ = cljs.core.first(arglist__8774);
var children__6683__auto__ = cljs.core.rest(arglist__8774);
return map__delegate(opts__6682__auto__,children__6683__auto__);
});
map.cljs$core$IFn$_invoke$arity$variadic = map__delegate;
return map;
})()
;
/**
* @param {...*} var_args
*/
om.dom.mark = (function() { 
var mark__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.mark.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var mark = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return mark__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
mark.cljs$lang$maxFixedArity = 1;
mark.cljs$lang$applyTo = (function (arglist__8775){
var opts__6682__auto__ = cljs.core.first(arglist__8775);
var children__6683__auto__ = cljs.core.rest(arglist__8775);
return mark__delegate(opts__6682__auto__,children__6683__auto__);
});
mark.cljs$core$IFn$_invoke$arity$variadic = mark__delegate;
return mark;
})()
;
/**
* @param {...*} var_args
*/
om.dom.menu = (function() { 
var menu__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.menu.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var menu = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return menu__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
menu.cljs$lang$maxFixedArity = 1;
menu.cljs$lang$applyTo = (function (arglist__8776){
var opts__6682__auto__ = cljs.core.first(arglist__8776);
var children__6683__auto__ = cljs.core.rest(arglist__8776);
return menu__delegate(opts__6682__auto__,children__6683__auto__);
});
menu.cljs$core$IFn$_invoke$arity$variadic = menu__delegate;
return menu;
})()
;
/**
* @param {...*} var_args
*/
om.dom.menuitem = (function() { 
var menuitem__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.menuitem.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var menuitem = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return menuitem__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
menuitem.cljs$lang$maxFixedArity = 1;
menuitem.cljs$lang$applyTo = (function (arglist__8777){
var opts__6682__auto__ = cljs.core.first(arglist__8777);
var children__6683__auto__ = cljs.core.rest(arglist__8777);
return menuitem__delegate(opts__6682__auto__,children__6683__auto__);
});
menuitem.cljs$core$IFn$_invoke$arity$variadic = menuitem__delegate;
return menuitem;
})()
;
/**
* @param {...*} var_args
*/
om.dom.meta = (function() { 
var meta__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.meta.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var meta = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return meta__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
meta.cljs$lang$maxFixedArity = 1;
meta.cljs$lang$applyTo = (function (arglist__8778){
var opts__6682__auto__ = cljs.core.first(arglist__8778);
var children__6683__auto__ = cljs.core.rest(arglist__8778);
return meta__delegate(opts__6682__auto__,children__6683__auto__);
});
meta.cljs$core$IFn$_invoke$arity$variadic = meta__delegate;
return meta;
})()
;
/**
* @param {...*} var_args
*/
om.dom.meter = (function() { 
var meter__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.meter.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var meter = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return meter__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
meter.cljs$lang$maxFixedArity = 1;
meter.cljs$lang$applyTo = (function (arglist__8779){
var opts__6682__auto__ = cljs.core.first(arglist__8779);
var children__6683__auto__ = cljs.core.rest(arglist__8779);
return meter__delegate(opts__6682__auto__,children__6683__auto__);
});
meter.cljs$core$IFn$_invoke$arity$variadic = meter__delegate;
return meter;
})()
;
/**
* @param {...*} var_args
*/
om.dom.nav = (function() { 
var nav__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.nav.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var nav = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return nav__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
nav.cljs$lang$maxFixedArity = 1;
nav.cljs$lang$applyTo = (function (arglist__8780){
var opts__6682__auto__ = cljs.core.first(arglist__8780);
var children__6683__auto__ = cljs.core.rest(arglist__8780);
return nav__delegate(opts__6682__auto__,children__6683__auto__);
});
nav.cljs$core$IFn$_invoke$arity$variadic = nav__delegate;
return nav;
})()
;
/**
* @param {...*} var_args
*/
om.dom.noscript = (function() { 
var noscript__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.noscript.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var noscript = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return noscript__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
noscript.cljs$lang$maxFixedArity = 1;
noscript.cljs$lang$applyTo = (function (arglist__8781){
var opts__6682__auto__ = cljs.core.first(arglist__8781);
var children__6683__auto__ = cljs.core.rest(arglist__8781);
return noscript__delegate(opts__6682__auto__,children__6683__auto__);
});
noscript.cljs$core$IFn$_invoke$arity$variadic = noscript__delegate;
return noscript;
})()
;
/**
* @param {...*} var_args
*/
om.dom.object = (function() { 
var object__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.object.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var object = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return object__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
object.cljs$lang$maxFixedArity = 1;
object.cljs$lang$applyTo = (function (arglist__8782){
var opts__6682__auto__ = cljs.core.first(arglist__8782);
var children__6683__auto__ = cljs.core.rest(arglist__8782);
return object__delegate(opts__6682__auto__,children__6683__auto__);
});
object.cljs$core$IFn$_invoke$arity$variadic = object__delegate;
return object;
})()
;
/**
* @param {...*} var_args
*/
om.dom.ol = (function() { 
var ol__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.ol.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var ol = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return ol__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
ol.cljs$lang$maxFixedArity = 1;
ol.cljs$lang$applyTo = (function (arglist__8783){
var opts__6682__auto__ = cljs.core.first(arglist__8783);
var children__6683__auto__ = cljs.core.rest(arglist__8783);
return ol__delegate(opts__6682__auto__,children__6683__auto__);
});
ol.cljs$core$IFn$_invoke$arity$variadic = ol__delegate;
return ol;
})()
;
/**
* @param {...*} var_args
*/
om.dom.optgroup = (function() { 
var optgroup__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.optgroup.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var optgroup = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return optgroup__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
optgroup.cljs$lang$maxFixedArity = 1;
optgroup.cljs$lang$applyTo = (function (arglist__8784){
var opts__6682__auto__ = cljs.core.first(arglist__8784);
var children__6683__auto__ = cljs.core.rest(arglist__8784);
return optgroup__delegate(opts__6682__auto__,children__6683__auto__);
});
optgroup.cljs$core$IFn$_invoke$arity$variadic = optgroup__delegate;
return optgroup;
})()
;
/**
* @param {...*} var_args
*/
om.dom.output = (function() { 
var output__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.output.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var output = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return output__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
output.cljs$lang$maxFixedArity = 1;
output.cljs$lang$applyTo = (function (arglist__8785){
var opts__6682__auto__ = cljs.core.first(arglist__8785);
var children__6683__auto__ = cljs.core.rest(arglist__8785);
return output__delegate(opts__6682__auto__,children__6683__auto__);
});
output.cljs$core$IFn$_invoke$arity$variadic = output__delegate;
return output;
})()
;
/**
* @param {...*} var_args
*/
om.dom.p = (function() { 
var p__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.p.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var p = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return p__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
p.cljs$lang$maxFixedArity = 1;
p.cljs$lang$applyTo = (function (arglist__8786){
var opts__6682__auto__ = cljs.core.first(arglist__8786);
var children__6683__auto__ = cljs.core.rest(arglist__8786);
return p__delegate(opts__6682__auto__,children__6683__auto__);
});
p.cljs$core$IFn$_invoke$arity$variadic = p__delegate;
return p;
})()
;
/**
* @param {...*} var_args
*/
om.dom.param = (function() { 
var param__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.param.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var param = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return param__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
param.cljs$lang$maxFixedArity = 1;
param.cljs$lang$applyTo = (function (arglist__8787){
var opts__6682__auto__ = cljs.core.first(arglist__8787);
var children__6683__auto__ = cljs.core.rest(arglist__8787);
return param__delegate(opts__6682__auto__,children__6683__auto__);
});
param.cljs$core$IFn$_invoke$arity$variadic = param__delegate;
return param;
})()
;
/**
* @param {...*} var_args
*/
om.dom.pre = (function() { 
var pre__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.pre.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var pre = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return pre__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
pre.cljs$lang$maxFixedArity = 1;
pre.cljs$lang$applyTo = (function (arglist__8788){
var opts__6682__auto__ = cljs.core.first(arglist__8788);
var children__6683__auto__ = cljs.core.rest(arglist__8788);
return pre__delegate(opts__6682__auto__,children__6683__auto__);
});
pre.cljs$core$IFn$_invoke$arity$variadic = pre__delegate;
return pre;
})()
;
/**
* @param {...*} var_args
*/
om.dom.progress = (function() { 
var progress__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.progress.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var progress = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return progress__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
progress.cljs$lang$maxFixedArity = 1;
progress.cljs$lang$applyTo = (function (arglist__8789){
var opts__6682__auto__ = cljs.core.first(arglist__8789);
var children__6683__auto__ = cljs.core.rest(arglist__8789);
return progress__delegate(opts__6682__auto__,children__6683__auto__);
});
progress.cljs$core$IFn$_invoke$arity$variadic = progress__delegate;
return progress;
})()
;
/**
* @param {...*} var_args
*/
om.dom.q = (function() { 
var q__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.q.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var q = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return q__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
q.cljs$lang$maxFixedArity = 1;
q.cljs$lang$applyTo = (function (arglist__8790){
var opts__6682__auto__ = cljs.core.first(arglist__8790);
var children__6683__auto__ = cljs.core.rest(arglist__8790);
return q__delegate(opts__6682__auto__,children__6683__auto__);
});
q.cljs$core$IFn$_invoke$arity$variadic = q__delegate;
return q;
})()
;
/**
* @param {...*} var_args
*/
om.dom.rp = (function() { 
var rp__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.rp.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var rp = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return rp__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
rp.cljs$lang$maxFixedArity = 1;
rp.cljs$lang$applyTo = (function (arglist__8791){
var opts__6682__auto__ = cljs.core.first(arglist__8791);
var children__6683__auto__ = cljs.core.rest(arglist__8791);
return rp__delegate(opts__6682__auto__,children__6683__auto__);
});
rp.cljs$core$IFn$_invoke$arity$variadic = rp__delegate;
return rp;
})()
;
/**
* @param {...*} var_args
*/
om.dom.rt = (function() { 
var rt__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.rt.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var rt = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return rt__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
rt.cljs$lang$maxFixedArity = 1;
rt.cljs$lang$applyTo = (function (arglist__8792){
var opts__6682__auto__ = cljs.core.first(arglist__8792);
var children__6683__auto__ = cljs.core.rest(arglist__8792);
return rt__delegate(opts__6682__auto__,children__6683__auto__);
});
rt.cljs$core$IFn$_invoke$arity$variadic = rt__delegate;
return rt;
})()
;
/**
* @param {...*} var_args
*/
om.dom.ruby = (function() { 
var ruby__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.ruby.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var ruby = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return ruby__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
ruby.cljs$lang$maxFixedArity = 1;
ruby.cljs$lang$applyTo = (function (arglist__8793){
var opts__6682__auto__ = cljs.core.first(arglist__8793);
var children__6683__auto__ = cljs.core.rest(arglist__8793);
return ruby__delegate(opts__6682__auto__,children__6683__auto__);
});
ruby.cljs$core$IFn$_invoke$arity$variadic = ruby__delegate;
return ruby;
})()
;
/**
* @param {...*} var_args
*/
om.dom.s = (function() { 
var s__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.s.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var s = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return s__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
s.cljs$lang$maxFixedArity = 1;
s.cljs$lang$applyTo = (function (arglist__8794){
var opts__6682__auto__ = cljs.core.first(arglist__8794);
var children__6683__auto__ = cljs.core.rest(arglist__8794);
return s__delegate(opts__6682__auto__,children__6683__auto__);
});
s.cljs$core$IFn$_invoke$arity$variadic = s__delegate;
return s;
})()
;
/**
* @param {...*} var_args
*/
om.dom.samp = (function() { 
var samp__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.samp.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var samp = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return samp__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
samp.cljs$lang$maxFixedArity = 1;
samp.cljs$lang$applyTo = (function (arglist__8795){
var opts__6682__auto__ = cljs.core.first(arglist__8795);
var children__6683__auto__ = cljs.core.rest(arglist__8795);
return samp__delegate(opts__6682__auto__,children__6683__auto__);
});
samp.cljs$core$IFn$_invoke$arity$variadic = samp__delegate;
return samp;
})()
;
/**
* @param {...*} var_args
*/
om.dom.script = (function() { 
var script__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.script.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var script = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return script__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
script.cljs$lang$maxFixedArity = 1;
script.cljs$lang$applyTo = (function (arglist__8796){
var opts__6682__auto__ = cljs.core.first(arglist__8796);
var children__6683__auto__ = cljs.core.rest(arglist__8796);
return script__delegate(opts__6682__auto__,children__6683__auto__);
});
script.cljs$core$IFn$_invoke$arity$variadic = script__delegate;
return script;
})()
;
/**
* @param {...*} var_args
*/
om.dom.section = (function() { 
var section__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.section.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var section = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return section__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
section.cljs$lang$maxFixedArity = 1;
section.cljs$lang$applyTo = (function (arglist__8797){
var opts__6682__auto__ = cljs.core.first(arglist__8797);
var children__6683__auto__ = cljs.core.rest(arglist__8797);
return section__delegate(opts__6682__auto__,children__6683__auto__);
});
section.cljs$core$IFn$_invoke$arity$variadic = section__delegate;
return section;
})()
;
/**
* @param {...*} var_args
*/
om.dom.select = (function() { 
var select__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.select.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var select = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return select__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
select.cljs$lang$maxFixedArity = 1;
select.cljs$lang$applyTo = (function (arglist__8798){
var opts__6682__auto__ = cljs.core.first(arglist__8798);
var children__6683__auto__ = cljs.core.rest(arglist__8798);
return select__delegate(opts__6682__auto__,children__6683__auto__);
});
select.cljs$core$IFn$_invoke$arity$variadic = select__delegate;
return select;
})()
;
/**
* @param {...*} var_args
*/
om.dom.small = (function() { 
var small__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.small.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var small = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return small__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
small.cljs$lang$maxFixedArity = 1;
small.cljs$lang$applyTo = (function (arglist__8799){
var opts__6682__auto__ = cljs.core.first(arglist__8799);
var children__6683__auto__ = cljs.core.rest(arglist__8799);
return small__delegate(opts__6682__auto__,children__6683__auto__);
});
small.cljs$core$IFn$_invoke$arity$variadic = small__delegate;
return small;
})()
;
/**
* @param {...*} var_args
*/
om.dom.source = (function() { 
var source__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.source.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var source = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return source__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
source.cljs$lang$maxFixedArity = 1;
source.cljs$lang$applyTo = (function (arglist__8800){
var opts__6682__auto__ = cljs.core.first(arglist__8800);
var children__6683__auto__ = cljs.core.rest(arglist__8800);
return source__delegate(opts__6682__auto__,children__6683__auto__);
});
source.cljs$core$IFn$_invoke$arity$variadic = source__delegate;
return source;
})()
;
/**
* @param {...*} var_args
*/
om.dom.span = (function() { 
var span__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.span.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var span = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return span__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
span.cljs$lang$maxFixedArity = 1;
span.cljs$lang$applyTo = (function (arglist__8801){
var opts__6682__auto__ = cljs.core.first(arglist__8801);
var children__6683__auto__ = cljs.core.rest(arglist__8801);
return span__delegate(opts__6682__auto__,children__6683__auto__);
});
span.cljs$core$IFn$_invoke$arity$variadic = span__delegate;
return span;
})()
;
/**
* @param {...*} var_args
*/
om.dom.strong = (function() { 
var strong__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.strong.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var strong = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return strong__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
strong.cljs$lang$maxFixedArity = 1;
strong.cljs$lang$applyTo = (function (arglist__8802){
var opts__6682__auto__ = cljs.core.first(arglist__8802);
var children__6683__auto__ = cljs.core.rest(arglist__8802);
return strong__delegate(opts__6682__auto__,children__6683__auto__);
});
strong.cljs$core$IFn$_invoke$arity$variadic = strong__delegate;
return strong;
})()
;
/**
* @param {...*} var_args
*/
om.dom.style = (function() { 
var style__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.style.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var style = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return style__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
style.cljs$lang$maxFixedArity = 1;
style.cljs$lang$applyTo = (function (arglist__8803){
var opts__6682__auto__ = cljs.core.first(arglist__8803);
var children__6683__auto__ = cljs.core.rest(arglist__8803);
return style__delegate(opts__6682__auto__,children__6683__auto__);
});
style.cljs$core$IFn$_invoke$arity$variadic = style__delegate;
return style;
})()
;
/**
* @param {...*} var_args
*/
om.dom.sub = (function() { 
var sub__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.sub.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var sub = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return sub__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
sub.cljs$lang$maxFixedArity = 1;
sub.cljs$lang$applyTo = (function (arglist__8804){
var opts__6682__auto__ = cljs.core.first(arglist__8804);
var children__6683__auto__ = cljs.core.rest(arglist__8804);
return sub__delegate(opts__6682__auto__,children__6683__auto__);
});
sub.cljs$core$IFn$_invoke$arity$variadic = sub__delegate;
return sub;
})()
;
/**
* @param {...*} var_args
*/
om.dom.summary = (function() { 
var summary__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.summary.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var summary = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return summary__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
summary.cljs$lang$maxFixedArity = 1;
summary.cljs$lang$applyTo = (function (arglist__8805){
var opts__6682__auto__ = cljs.core.first(arglist__8805);
var children__6683__auto__ = cljs.core.rest(arglist__8805);
return summary__delegate(opts__6682__auto__,children__6683__auto__);
});
summary.cljs$core$IFn$_invoke$arity$variadic = summary__delegate;
return summary;
})()
;
/**
* @param {...*} var_args
*/
om.dom.sup = (function() { 
var sup__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.sup.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var sup = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return sup__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
sup.cljs$lang$maxFixedArity = 1;
sup.cljs$lang$applyTo = (function (arglist__8806){
var opts__6682__auto__ = cljs.core.first(arglist__8806);
var children__6683__auto__ = cljs.core.rest(arglist__8806);
return sup__delegate(opts__6682__auto__,children__6683__auto__);
});
sup.cljs$core$IFn$_invoke$arity$variadic = sup__delegate;
return sup;
})()
;
/**
* @param {...*} var_args
*/
om.dom.table = (function() { 
var table__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.table.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var table = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return table__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
table.cljs$lang$maxFixedArity = 1;
table.cljs$lang$applyTo = (function (arglist__8807){
var opts__6682__auto__ = cljs.core.first(arglist__8807);
var children__6683__auto__ = cljs.core.rest(arglist__8807);
return table__delegate(opts__6682__auto__,children__6683__auto__);
});
table.cljs$core$IFn$_invoke$arity$variadic = table__delegate;
return table;
})()
;
/**
* @param {...*} var_args
*/
om.dom.tbody = (function() { 
var tbody__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.tbody.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var tbody = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return tbody__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
tbody.cljs$lang$maxFixedArity = 1;
tbody.cljs$lang$applyTo = (function (arglist__8808){
var opts__6682__auto__ = cljs.core.first(arglist__8808);
var children__6683__auto__ = cljs.core.rest(arglist__8808);
return tbody__delegate(opts__6682__auto__,children__6683__auto__);
});
tbody.cljs$core$IFn$_invoke$arity$variadic = tbody__delegate;
return tbody;
})()
;
/**
* @param {...*} var_args
*/
om.dom.td = (function() { 
var td__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.td.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var td = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return td__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
td.cljs$lang$maxFixedArity = 1;
td.cljs$lang$applyTo = (function (arglist__8809){
var opts__6682__auto__ = cljs.core.first(arglist__8809);
var children__6683__auto__ = cljs.core.rest(arglist__8809);
return td__delegate(opts__6682__auto__,children__6683__auto__);
});
td.cljs$core$IFn$_invoke$arity$variadic = td__delegate;
return td;
})()
;
/**
* @param {...*} var_args
*/
om.dom.tfoot = (function() { 
var tfoot__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.tfoot.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var tfoot = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return tfoot__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
tfoot.cljs$lang$maxFixedArity = 1;
tfoot.cljs$lang$applyTo = (function (arglist__8810){
var opts__6682__auto__ = cljs.core.first(arglist__8810);
var children__6683__auto__ = cljs.core.rest(arglist__8810);
return tfoot__delegate(opts__6682__auto__,children__6683__auto__);
});
tfoot.cljs$core$IFn$_invoke$arity$variadic = tfoot__delegate;
return tfoot;
})()
;
/**
* @param {...*} var_args
*/
om.dom.th = (function() { 
var th__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.th.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var th = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return th__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
th.cljs$lang$maxFixedArity = 1;
th.cljs$lang$applyTo = (function (arglist__8811){
var opts__6682__auto__ = cljs.core.first(arglist__8811);
var children__6683__auto__ = cljs.core.rest(arglist__8811);
return th__delegate(opts__6682__auto__,children__6683__auto__);
});
th.cljs$core$IFn$_invoke$arity$variadic = th__delegate;
return th;
})()
;
/**
* @param {...*} var_args
*/
om.dom.thead = (function() { 
var thead__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.thead.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var thead = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return thead__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
thead.cljs$lang$maxFixedArity = 1;
thead.cljs$lang$applyTo = (function (arglist__8812){
var opts__6682__auto__ = cljs.core.first(arglist__8812);
var children__6683__auto__ = cljs.core.rest(arglist__8812);
return thead__delegate(opts__6682__auto__,children__6683__auto__);
});
thead.cljs$core$IFn$_invoke$arity$variadic = thead__delegate;
return thead;
})()
;
/**
* @param {...*} var_args
*/
om.dom.time = (function() { 
var time__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.time.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var time = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return time__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
time.cljs$lang$maxFixedArity = 1;
time.cljs$lang$applyTo = (function (arglist__8813){
var opts__6682__auto__ = cljs.core.first(arglist__8813);
var children__6683__auto__ = cljs.core.rest(arglist__8813);
return time__delegate(opts__6682__auto__,children__6683__auto__);
});
time.cljs$core$IFn$_invoke$arity$variadic = time__delegate;
return time;
})()
;
/**
* @param {...*} var_args
*/
om.dom.title = (function() { 
var title__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.title.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var title = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return title__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
title.cljs$lang$maxFixedArity = 1;
title.cljs$lang$applyTo = (function (arglist__8814){
var opts__6682__auto__ = cljs.core.first(arglist__8814);
var children__6683__auto__ = cljs.core.rest(arglist__8814);
return title__delegate(opts__6682__auto__,children__6683__auto__);
});
title.cljs$core$IFn$_invoke$arity$variadic = title__delegate;
return title;
})()
;
/**
* @param {...*} var_args
*/
om.dom.tr = (function() { 
var tr__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.tr.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var tr = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return tr__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
tr.cljs$lang$maxFixedArity = 1;
tr.cljs$lang$applyTo = (function (arglist__8815){
var opts__6682__auto__ = cljs.core.first(arglist__8815);
var children__6683__auto__ = cljs.core.rest(arglist__8815);
return tr__delegate(opts__6682__auto__,children__6683__auto__);
});
tr.cljs$core$IFn$_invoke$arity$variadic = tr__delegate;
return tr;
})()
;
/**
* @param {...*} var_args
*/
om.dom.track = (function() { 
var track__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.track.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var track = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return track__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
track.cljs$lang$maxFixedArity = 1;
track.cljs$lang$applyTo = (function (arglist__8816){
var opts__6682__auto__ = cljs.core.first(arglist__8816);
var children__6683__auto__ = cljs.core.rest(arglist__8816);
return track__delegate(opts__6682__auto__,children__6683__auto__);
});
track.cljs$core$IFn$_invoke$arity$variadic = track__delegate;
return track;
})()
;
/**
* @param {...*} var_args
*/
om.dom.u = (function() { 
var u__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.u.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var u = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return u__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
u.cljs$lang$maxFixedArity = 1;
u.cljs$lang$applyTo = (function (arglist__8817){
var opts__6682__auto__ = cljs.core.first(arglist__8817);
var children__6683__auto__ = cljs.core.rest(arglist__8817);
return u__delegate(opts__6682__auto__,children__6683__auto__);
});
u.cljs$core$IFn$_invoke$arity$variadic = u__delegate;
return u;
})()
;
/**
* @param {...*} var_args
*/
om.dom.ul = (function() { 
var ul__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.ul.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var ul = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return ul__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
ul.cljs$lang$maxFixedArity = 1;
ul.cljs$lang$applyTo = (function (arglist__8818){
var opts__6682__auto__ = cljs.core.first(arglist__8818);
var children__6683__auto__ = cljs.core.rest(arglist__8818);
return ul__delegate(opts__6682__auto__,children__6683__auto__);
});
ul.cljs$core$IFn$_invoke$arity$variadic = ul__delegate;
return ul;
})()
;
/**
* @param {...*} var_args
*/
om.dom.var$ = (function() { 
var var$__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.var$.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var var$ = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return var$__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
var$.cljs$lang$maxFixedArity = 1;
var$.cljs$lang$applyTo = (function (arglist__8819){
var opts__6682__auto__ = cljs.core.first(arglist__8819);
var children__6683__auto__ = cljs.core.rest(arglist__8819);
return var$__delegate(opts__6682__auto__,children__6683__auto__);
});
var$.cljs$core$IFn$_invoke$arity$variadic = var$__delegate;
return var$;
})()
;
/**
* @param {...*} var_args
*/
om.dom.video = (function() { 
var video__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.video.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var video = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return video__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
video.cljs$lang$maxFixedArity = 1;
video.cljs$lang$applyTo = (function (arglist__8820){
var opts__6682__auto__ = cljs.core.first(arglist__8820);
var children__6683__auto__ = cljs.core.rest(arglist__8820);
return video__delegate(opts__6682__auto__,children__6683__auto__);
});
video.cljs$core$IFn$_invoke$arity$variadic = video__delegate;
return video;
})()
;
/**
* @param {...*} var_args
*/
om.dom.wbr = (function() { 
var wbr__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.wbr.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var wbr = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return wbr__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
wbr.cljs$lang$maxFixedArity = 1;
wbr.cljs$lang$applyTo = (function (arglist__8821){
var opts__6682__auto__ = cljs.core.first(arglist__8821);
var children__6683__auto__ = cljs.core.rest(arglist__8821);
return wbr__delegate(opts__6682__auto__,children__6683__auto__);
});
wbr.cljs$core$IFn$_invoke$arity$variadic = wbr__delegate;
return wbr;
})()
;
/**
* @param {...*} var_args
*/
om.dom.circle = (function() { 
var circle__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.circle.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var circle = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return circle__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
circle.cljs$lang$maxFixedArity = 1;
circle.cljs$lang$applyTo = (function (arglist__8822){
var opts__6682__auto__ = cljs.core.first(arglist__8822);
var children__6683__auto__ = cljs.core.rest(arglist__8822);
return circle__delegate(opts__6682__auto__,children__6683__auto__);
});
circle.cljs$core$IFn$_invoke$arity$variadic = circle__delegate;
return circle;
})()
;
/**
* @param {...*} var_args
*/
om.dom.ellipse = (function() { 
var ellipse__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.ellipse.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var ellipse = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return ellipse__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
ellipse.cljs$lang$maxFixedArity = 1;
ellipse.cljs$lang$applyTo = (function (arglist__8823){
var opts__6682__auto__ = cljs.core.first(arglist__8823);
var children__6683__auto__ = cljs.core.rest(arglist__8823);
return ellipse__delegate(opts__6682__auto__,children__6683__auto__);
});
ellipse.cljs$core$IFn$_invoke$arity$variadic = ellipse__delegate;
return ellipse;
})()
;
/**
* @param {...*} var_args
*/
om.dom.g = (function() { 
var g__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.g.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var g = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return g__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
g.cljs$lang$maxFixedArity = 1;
g.cljs$lang$applyTo = (function (arglist__8824){
var opts__6682__auto__ = cljs.core.first(arglist__8824);
var children__6683__auto__ = cljs.core.rest(arglist__8824);
return g__delegate(opts__6682__auto__,children__6683__auto__);
});
g.cljs$core$IFn$_invoke$arity$variadic = g__delegate;
return g;
})()
;
/**
* @param {...*} var_args
*/
om.dom.line = (function() { 
var line__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.line.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var line = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return line__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
line.cljs$lang$maxFixedArity = 1;
line.cljs$lang$applyTo = (function (arglist__8825){
var opts__6682__auto__ = cljs.core.first(arglist__8825);
var children__6683__auto__ = cljs.core.rest(arglist__8825);
return line__delegate(opts__6682__auto__,children__6683__auto__);
});
line.cljs$core$IFn$_invoke$arity$variadic = line__delegate;
return line;
})()
;
/**
* @param {...*} var_args
*/
om.dom.path = (function() { 
var path__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.path.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var path = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return path__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
path.cljs$lang$maxFixedArity = 1;
path.cljs$lang$applyTo = (function (arglist__8826){
var opts__6682__auto__ = cljs.core.first(arglist__8826);
var children__6683__auto__ = cljs.core.rest(arglist__8826);
return path__delegate(opts__6682__auto__,children__6683__auto__);
});
path.cljs$core$IFn$_invoke$arity$variadic = path__delegate;
return path;
})()
;
/**
* @param {...*} var_args
*/
om.dom.polyline = (function() { 
var polyline__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.polyline.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var polyline = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return polyline__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
polyline.cljs$lang$maxFixedArity = 1;
polyline.cljs$lang$applyTo = (function (arglist__8827){
var opts__6682__auto__ = cljs.core.first(arglist__8827);
var children__6683__auto__ = cljs.core.rest(arglist__8827);
return polyline__delegate(opts__6682__auto__,children__6683__auto__);
});
polyline.cljs$core$IFn$_invoke$arity$variadic = polyline__delegate;
return polyline;
})()
;
/**
* @param {...*} var_args
*/
om.dom.rect = (function() { 
var rect__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.rect.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var rect = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return rect__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
rect.cljs$lang$maxFixedArity = 1;
rect.cljs$lang$applyTo = (function (arglist__8828){
var opts__6682__auto__ = cljs.core.first(arglist__8828);
var children__6683__auto__ = cljs.core.rest(arglist__8828);
return rect__delegate(opts__6682__auto__,children__6683__auto__);
});
rect.cljs$core$IFn$_invoke$arity$variadic = rect__delegate;
return rect;
})()
;
/**
* @param {...*} var_args
*/
om.dom.svg = (function() { 
var svg__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.svg.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var svg = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return svg__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
svg.cljs$lang$maxFixedArity = 1;
svg.cljs$lang$applyTo = (function (arglist__8829){
var opts__6682__auto__ = cljs.core.first(arglist__8829);
var children__6683__auto__ = cljs.core.rest(arglist__8829);
return svg__delegate(opts__6682__auto__,children__6683__auto__);
});
svg.cljs$core$IFn$_invoke$arity$variadic = svg__delegate;
return svg;
})()
;
/**
* @param {...*} var_args
*/
om.dom.text = (function() { 
var text__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.text.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var text = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return text__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
text.cljs$lang$maxFixedArity = 1;
text.cljs$lang$applyTo = (function (arglist__8830){
var opts__6682__auto__ = cljs.core.first(arglist__8830);
var children__6683__auto__ = cljs.core.rest(arglist__8830);
return text__delegate(opts__6682__auto__,children__6683__auto__);
});
text.cljs$core$IFn$_invoke$arity$variadic = text__delegate;
return text;
})()
;
/**
* @param {...*} var_args
*/
om.dom.defs = (function() { 
var defs__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.defs.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var defs = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return defs__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
defs.cljs$lang$maxFixedArity = 1;
defs.cljs$lang$applyTo = (function (arglist__8831){
var opts__6682__auto__ = cljs.core.first(arglist__8831);
var children__6683__auto__ = cljs.core.rest(arglist__8831);
return defs__delegate(opts__6682__auto__,children__6683__auto__);
});
defs.cljs$core$IFn$_invoke$arity$variadic = defs__delegate;
return defs;
})()
;
/**
* @param {...*} var_args
*/
om.dom.linearGradient = (function() { 
var linearGradient__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.linearGradient.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var linearGradient = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return linearGradient__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
linearGradient.cljs$lang$maxFixedArity = 1;
linearGradient.cljs$lang$applyTo = (function (arglist__8832){
var opts__6682__auto__ = cljs.core.first(arglist__8832);
var children__6683__auto__ = cljs.core.rest(arglist__8832);
return linearGradient__delegate(opts__6682__auto__,children__6683__auto__);
});
linearGradient.cljs$core$IFn$_invoke$arity$variadic = linearGradient__delegate;
return linearGradient;
})()
;
/**
* @param {...*} var_args
*/
om.dom.polygon = (function() { 
var polygon__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.polygon.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var polygon = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return polygon__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
polygon.cljs$lang$maxFixedArity = 1;
polygon.cljs$lang$applyTo = (function (arglist__8833){
var opts__6682__auto__ = cljs.core.first(arglist__8833);
var children__6683__auto__ = cljs.core.rest(arglist__8833);
return polygon__delegate(opts__6682__auto__,children__6683__auto__);
});
polygon.cljs$core$IFn$_invoke$arity$variadic = polygon__delegate;
return polygon;
})()
;
/**
* @param {...*} var_args
*/
om.dom.radialGradient = (function() { 
var radialGradient__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.radialGradient.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var radialGradient = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return radialGradient__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
radialGradient.cljs$lang$maxFixedArity = 1;
radialGradient.cljs$lang$applyTo = (function (arglist__8834){
var opts__6682__auto__ = cljs.core.first(arglist__8834);
var children__6683__auto__ = cljs.core.rest(arglist__8834);
return radialGradient__delegate(opts__6682__auto__,children__6683__auto__);
});
radialGradient.cljs$core$IFn$_invoke$arity$variadic = radialGradient__delegate;
return radialGradient;
})()
;
/**
* @param {...*} var_args
*/
om.dom.stop = (function() { 
var stop__delegate = function (opts__6682__auto__,children__6683__auto__){return React.DOM.stop.apply(null,cljs.core.into_array.call(null,cljs.core.cons.call(null,opts__6682__auto__,children__6683__auto__)));
};
var stop = function (opts__6682__auto__,var_args){
var children__6683__auto__ = null;if (arguments.length > 1) {
  children__6683__auto__ = cljs.core.array_seq(Array.prototype.slice.call(arguments, 1),0);} 
return stop__delegate.call(this,opts__6682__auto__,children__6683__auto__);};
stop.cljs$lang$maxFixedArity = 1;
stop.cljs$lang$applyTo = (function (arglist__8835){
var opts__6682__auto__ = cljs.core.first(arglist__8835);
var children__6683__auto__ = cljs.core.rest(arglist__8835);
return stop__delegate(opts__6682__auto__,children__6683__auto__);
});
stop.cljs$core$IFn$_invoke$arity$variadic = stop__delegate;
return stop;
})()
;
om.dom.wrap_form_element = (function wrap_form_element(ctor,display_name){return React.createClass({"render": (function (){var this$ = this;return this$.transferPropsTo(ctor.call(null,{"children": (this$.props["children"]), "onChange": (this$["onChange"]), "value": (this$.state["value"])}));
}), "componentWillReceiveProps": (function (new_props){var this$ = this;return this$.setState({"value": (new_props["value"])});
}), "onChange": (function (e){var this$ = this;var handler = (this$.props["onChange"]);if((handler == null))
{return null;
} else
{handler.call(null,e);
return this$.setState({"value": e.target.value});
}
}), "getInitialState": (function (){var this$ = this;return {"value": (this$.props["value"])};
}), "getDisplayName": (function (){return display_name;
})});
});
om.dom.input = om.dom.wrap_form_element.call(null,React.DOM.input,"input");
om.dom.textarea = om.dom.wrap_form_element.call(null,React.DOM.textarea,"textarea");
om.dom.option = om.dom.wrap_form_element.call(null,React.DOM.option,"option");
/**
* Equivalent to React.renderComponent
*/
om.dom.render = (function render(component,el){return React.renderComponent(component,el);
});
/**
* Equivalent to React.renderComponentToString
*/
om.dom.render_to_str = (function render_to_str(c){return React.renderComponentToString(c);
});

//# sourceMappingURL=dom.js.map