// Compiled by ClojureScript 0.0-2234
goog.provide('tamarack.history');
goog.require('cljs.core');
goog.require('goog.history.EventType');
goog.require('goog.History');
goog.require('goog.events');
goog.require('goog.events');
tamarack.history.history = (new goog.History());

//# sourceMappingURL=history.js.map